/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.dl;

public record SpanEnd(int index, int characterEnd) {

  @Deprecated(forRemoval = true)
  public int getIndex() {
    return index;
  }
  
  @Deprecated(forRemoval = true)
  public int getCharacterEnd() {
    return characterEnd;
  }

  @Override
  public String toString() {
    return "index: " + index + "; character end: " + characterEnd;
  }

}
